function Nv3kV200ns = importfile1(filename, dataLines)
%IMPORTFILE1 Import data from a text file
%  NV3KV200NS = IMPORTFILE1(FILENAME) reads data from text file FILENAME
%  for the default selection.  Returns the numeric data.
%
%  NV3KV200NS = IMPORTFILE1(FILE, DATALINES) reads data for the
%  specified row interval(s) of text file FILENAME. Specify DATALINES as
%  a positive scalar integer or a N-by-2 array of positive scalar
%  integers for dis-contiguous row intervals.
%
%  Example:
%  Nv3kV200ns = importfile1("/home/he/1_PhD/2_nsAPPJ_Paper/1_Simulation/1_Validation/20210601_multiLokiCall/N2vib_2_MultiLokiDuringPulseOn_2_4Lokicalls/0_data_A1_A2/210504/Nv_3kV_200ns.csv", [2, Inf]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 24-Sep-2021 16:37:45

%% Input handling

% If dataLines is not specified, define defaults
if nargin < 2
    dataLines = [2, Inf];
end

%% Set up the Import Options and import the data
opts = delimitedTextImportOptions("NumVariables", 6);

% Specify range and delimiter
opts.DataLines = dataLines;
opts.Delimiter = ",";

% Specify column names and types
opts.VariableNames = ["TimeNs", "N0", "N1", "N2", "N3", "N4"];
opts.VariableTypes = ["double", "double", "double", "double", "double", "double"];

% Specify file level properties
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";

% Import the data
Nv3kV200ns = readtable(filename, opts);

%% Convert to output type
Nv3kV200ns = table2array(Nv3kV200ns);
end